# An example rule file
x <- 3

y <- 4 
